pecos.noise\_models.general\_noise
==================================

.. automodule:: pecos.noise_models.general_noise











   .. rubric:: Classes

   .. autosummary::

      GeneralNoiseModel
